==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/GetUserHierarchyGroupHierarchyPath.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives Details of level five. See below.
 * @property levelFours Details of level four. See below.
 * @property levelOnes Details of level one. See below.
 * @property levelThrees Details of level three. See below.
 * @property levelTwos Details of level two. See below.
 */
public data class GetUserHierarchyGroupHierarchyPath(
    public val levelFives: List<GetUserHierarchyGroupHierarchyPathLevelFife>,
    public val levelFours: List<GetUserHierarchyGroupHierarchyPathLevelFour>,
    public val levelOnes: List<GetUserHierarchyGroupHierarchyPathLevelOne>,
    public val levelThrees: List<GetUserHierarchyGroupHierarchyPathLevelThree>,
    public val levelTwos: List<GetUserHierarchyGroupHierarchyPathLevelTwo>,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.connect.outputs.GetUserHierarchyGroupHierarchyPath):
            GetUserHierarchyGroupHierarchyPath = GetUserHierarchyGroupHierarchyPath(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/connect/kotlin/outputs/GetUserHierarchyGroupHierarchyPath.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.connect.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property levelFives Details of level five. See below.
 * @property levelFours Details of level four. See below.
 * @property levelOnes Details of level one. See below.
 * @property levelThrees Details of level three. See below.
 * @property levelTwos Details of level two. See below.
 */
public data class GetUserHierarchyGroupHierarchyPath(
    public val levelFives: List<GetUserHierarchyGroupHierarchyPathLevelFife>,
    public val levelFours: List<GetUserHierarchyGroupHierarchyPathLevelFour>,
    public val levelOnes: List<GetUserHierarchyGroupHierarchyPathLevelOne>,
    public val levelThrees: List<GetUserHierarchyGroupHierarchyPathLevelThree>,
    public val levelTwos: List<GetUserHierarchyGroupHierarchyPathLevelTwo>,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.connect.outputs.GetUserHierarchyGroupHierarchyPath): GetUserHierarchyGroupHierarchyPath = GetUserHierarchyGroupHierarchyPath(
            levelFives = javaType.levelFives().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelFife.Companion.toKotlin(args0)
                })
            }),
            levelFours = javaType.levelFours().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelFour.Companion.toKotlin(args0)
                })
            }),
            levelOnes = javaType.levelOnes().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelOne.Companion.toKotlin(args0)
                })
            }),
            levelThrees = javaType.levelThrees().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelThree.Companion.toKotlin(args0)
                })
            }),
            levelTwos = javaType.levelTwos().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.connect.kotlin.outputs.GetUserHierarchyGroupHierarchyPathLevelTwo.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
